@@ -27,7 +27,6 @@
 #    Web:    http://www.geno-project.org
 
 import warnings
-import sys
 
 class OptimizeResult(dict):
     def __getattr__(self, name):
@@ -65,6 +64,7 @@ class LBFGSB:
         self.set_options(options)
         self.init_matrices()
         self.working = np.full(self.n, 1.0)
+        self.inf_array = np.full(self.n, np.inf)
 
     def all_options(self):
         return {'verbose', 'max_iter', 'step_max', 'max_ls',
@@ -125,8 +125,8 @@ class LBFGSB:
     def max_step_size(self, x, d):
         np = self.np
         if self.constrained:
-            step_ub = np.where(d > 0, np.divide(self.ub - x, d + sys.float_info.min), np.inf)
-            step_lb = np.where(d < 0, np.divide(self.lb - x, d - sys.float_info.min), np.inf)
+            step_ub = np.divide(self.ub - x, d, out=self.inf_array, where=d>0)
+            step_lb = np.divide(self.lb - x, d, out=self.inf_array, where=d<0)
             step_max = min(np.min(step_ub), np.min(step_lb))
         else:
             step_max = np.inf
@@ -485,6 +485,11 @@ def minimize(fg, x0, lb=None, ub=None, options=None, constraints=None, np=None):
         import numpy as np
     if options is None:
         options = {}
+    x0 = np.ascontiguousarray(x0)
+    if not lb is None:
+        lb = np.ascontiguousarray(lb)
+    if not ub is None:
+        ub = np.ascontiguousarray(ub)
     if not constraints:
         solver = LBFGSB(fg, x0, np, lb, ub, options)
     else:
